@@ -18,9 +18,9 @@
 # along with lavacli.  If not, see <http://www.gnu.org/licenses/>
 
 import os
-import yaml
+import sys
 
-from lavacli.utils import loader
+from lavacli.utils import flow_yaml, safe_yaml
 
 
 class ConfigurationError(Exception):
@@ -63,9 +63,7 @@ def _load_configuration():
 
     try:
         with open(config_filename, "r", encoding="utf-8") as f_conf:
-            data = yaml.load(  # nosec - loader() returns a safe loader
-                f_conf.read(), Loader=loader()
-            )
+            data = safe_yaml.load(f_conf.read())
             if not isinstance(data, dict):
                 raise ConfigurationError("Invalid configuration file")
             return data
@@ -82,7 +80,7 @@ def _save_configuration(config):
         os.makedirs(expanded_config_dir)
 
     with open(config_filename, "w", encoding="utf-8") as f_conf:
-        f_conf.write(yaml.safe_dump(config, default_flow_style=False).rstrip("\n"))
+        flow_yaml.dump(config, f_conf)
 
 
 def handle_add(_, options):
@@ -121,8 +119,7 @@ def handle_list(_, __):
 def handle_show(_, options):
     config = _load_configuration()
     try:
-        conf_str = yaml.safe_dump(config[options.id], default_flow_style=False)
-        print(conf_str.rstrip("\n"))
+        flow_yaml.dump(config[options.id], sys.stdout)
         return 0
     except KeyError:
         print("Unknown identity '%s'" % options.id)
