@@ -21,7 +21,6 @@ import json
 import sys
 import time
 import xmlrpc.client
-import yaml
 
 from lavacli import main
 
@@ -258,6 +257,25 @@ def test_devices_add_2_after_2018_1(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == ""  # nosec
 
 
+def test_devices_dict_delete(setup, monkeypatch, capsys):
+    version = "2022.4"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "devices", "dict", "delete", "qemu01"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.devices.set_dictionary",
+                "args": ("qemu01", ""),
+                "ret": True,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_devices_dict_get(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(sys, "argv", ["lavacli", "devices", "dict", "get", "qemu01"])
@@ -292,7 +310,7 @@ def test_devices_dict_get_render_field(setup, monkeypatch, capsys):
             {
                 "request": "scheduler.devices.get_dictionary",
                 "args": ("qemu01", True, None),
-                "ret": yaml.dump({"hello": [{"world": "as usual"}, "my"]}),
+                "ret": """{"hello": [{"world": "as usual"}, "my"]}""",
             },
         ],
     )
@@ -315,7 +333,7 @@ def test_devices_dict_get_render_field_out_of_range(setup, monkeypatch, capsys):
             {
                 "request": "scheduler.devices.get_dictionary",
                 "args": ("qemu01", True, None),
-                "ret": yaml.dump({"hello": [{"world": "as usual"}, "my"]}),
+                "ret": """{"hello": [{"world": "as usual"}, "my"]}""",
             },
         ],
     )
@@ -338,7 +356,7 @@ def test_devices_dict_get_render_field_missing(setup, monkeypatch, capsys):
             {
                 "request": "scheduler.devices.get_dictionary",
                 "args": ("qemu01", True, None),
-                "ret": yaml.dump({"hello": [{"world": "as usual"}, "my"]}),
+                "ret": """{"hello": [{"world": "as usual"}, "my"]}""",
             },
         ],
     )
@@ -363,7 +381,7 @@ def test_devices_dict_get_render_field_missing_1(setup, monkeypatch, capsys):
             {
                 "request": "scheduler.devices.get_dictionary",
                 "args": ("qemu01", True, None),
-                "ret": yaml.dump({"hello": [{"world": "as usual"}, "my"]}),
+                "ret": """{"hello": [{"world": "as usual"}, "my"]}""",
             },
         ],
     )
@@ -396,7 +414,7 @@ def test_devices_dict_get_render_field_missing_2(setup, monkeypatch, capsys):
             {
                 "request": "scheduler.devices.get_dictionary",
                 "args": ("qemu01", True, None),
-                "ret": yaml.dump({"hello": [{"world": "as usual"}, "my"]}),
+                "ret": """{"hello": [{"world": "as usual"}, "my"]}""",
             },
         ],
     )
